erin package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   erin.cli
   erin.core
   erin.db

Submodules
----------

erin.app module
---------------

.. automodule:: erin.app
   :members:
   :undoc-members:
   :show-inheritance:

erin.client module
------------------

.. automodule:: erin.client
   :members:
   :undoc-members:
   :show-inheritance:

erin.utils module
-----------------

.. automodule:: erin.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: erin
   :members:
   :undoc-members:
   :show-inheritance:
